emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 95e8c7d 1/2: ; Fix typos


From: Stefan Kangas
Subject: master 95e8c7d 1/2: ; Fix typos
Date: Fri, 9 Oct 2020 09:42:51 -0400 (EDT)

branch: master
commit 95e8c7d1d9ec9476065958596acfa97cf960b9db
Author: Stefan Kangas <stefan@marxist.se>
Commit: Stefan Kangas <stefan@marxist.se>

    ; Fix typos
---
 ChangeLog.1                               |  2 +-
 ChangeLog.3                               |  6 +++---
 lisp/ChangeLog.12                         |  4 ++--
 lisp/ChangeLog.17                         |  4 ++--
 lisp/cedet/semantic.el                    | 10 +++++-----
 src/ChangeLog.11                          |  2 +-
 test/manual/etags/CTAGS.good              |  2 +-
 test/manual/etags/cp-src/functions.cpp    |  2 +-
 test/manual/etags/prol-src/ordsets.prolog |  4 ++--
 test/manual/etags/tex-src/texinfo.tex     |  4 ++--
 10 files changed, 20 insertions(+), 20 deletions(-)

diff --git a/ChangeLog.1 b/ChangeLog.1
index 1fb7b78..b01a316 100644
--- a/ChangeLog.1
+++ b/ChangeLog.1
@@ -3528,7 +3528,7 @@
        Port to Solaris 8.
        Without this change, 'configure' fails because the recently-added
        wait3 prototype in config.h messes up later 'configure' tests.
-       Fix this problem by droping wait3 and WRETCODE, as they're
+       Fix this problem by dropping wait3 and WRETCODE, as they're
        no longer needed on hosts that are current porting targets.
        * configure.ac (wait3, WRETCODE): Remove, fixing a FIXME.
        All uses changed to waitpid and WEXITSTATUS.
diff --git a/ChangeLog.3 b/ChangeLog.3
index 16e74f4..c9aaedf 100644
--- a/ChangeLog.3
+++ b/ChangeLog.3
@@ -65735,7 +65735,7 @@
 
 2018-04-05  Tino Calancha  <tino.calancha@gmail.com>
 
-       Require secrets.el iif Emacs has dbusbind support
+       Require secrets.el if Emacs has dbusbind support
 
        * test/lisp/net/secrets-tests.el: Require secrets.el if
        and only if, Emacs has been compiled with dbusbind support.
@@ -71454,7 +71454,7 @@
        In the macro expansion of the example above, right after:
        (setq k (+ k 1))
 
-       evaluate the rest of the body forms iif the condition
+       evaluate the rest of the body forms if the condition
        (< k 2)
        is still valid.
 
@@ -114927,7 +114927,7 @@
 
 2017-01-28  Yuri D'Elia  <wavexx@thregr.org>
 
-       Subject: Check Bcc after the Messag hook has run
+       Subject: Check Bcc after the Message hook has run
 
        * lisp/gnus/message.el (message-send): If the hook modifies
        the message (mml tags or headers), we should check bcc on the
diff --git a/lisp/ChangeLog.12 b/lisp/ChangeLog.12
index a9d0067..40aa8c4 100644
--- a/lisp/ChangeLog.12
+++ b/lisp/ChangeLog.12
@@ -16274,7 +16274,7 @@
 
        (c-guess-basic-syntax): Adapt case 5B for the new
        `c-just-after-func-arglist-p'.  Merge cases 5B.1 and 5B.3.
-       Remove cases 5D.1 and 5D.2 since they aren't trigged anymore (case 5B.1
+       Remove cases 5D.1 and 5D.2 since they aren't triggered anymore (case 
5B.1
        covers all cases now).
 
        * progmodes/cc-defs.el (c-point): Add `bosws' and `eosws'.
@@ -32889,7 +32889,7 @@
 
 2005-01-14  Nick Roberts  <nickrob@snap.net.nz>
 
-       * xt-mouse.el (xterm-mouse-event): Compute window co-ordinates
+       * xt-mouse.el (xterm-mouse-event): Compute window coordinates
        more carefully.
 
 2005-01-13  Stefan Monnier  <monnier@iro.umontreal.ca>
diff --git a/lisp/ChangeLog.17 b/lisp/ChangeLog.17
index 1869f4e..8039e3f 100644
--- a/lisp/ChangeLog.17
+++ b/lisp/ChangeLog.17
@@ -6540,8 +6540,8 @@
        (newsticker--image-get): New arguments FILENAME and DIRECTORY.
        Use `url-retrieve' if `newsticker-retrieval-method' is 'intern.
        (newsticker--image-download-by-wget): New.  Use process properties
-       for storing informations.
-       (newsticker--image-sentinel): Read informations from process properties.
+       for storing information.
+       (newsticker--image-sentinel): Read information from process properties.
        (newsticker--image-save)
        (newsticker--image-remove)
        (newsticker--image-download-by-url)
diff --git a/src/ChangeLog.11 b/src/ChangeLog.11
index 1086d11..cf9e87a 100644
--- a/src/ChangeLog.11
+++ b/src/ChangeLog.11
@@ -10126,7 +10126,7 @@
 
 2010-01-06  Jan Djärv  <jan.h.d@swipnet.se>
 
-       * font.c (font_open_entity): Enable chache and call cached_font_ok
+       * font.c (font_open_entity): Enable cache and call cached_font_ok
        for the driver if defined.
        (QCuser_spec): New symbol.
        (font_spec_from_name): Save name as user-spec.
diff --git a/test/manual/etags/CTAGS.good b/test/manual/etags/CTAGS.good
index 519315c..5e58243 100644
--- a/test/manual/etags/CTAGS.good
+++ b/test/manual/etags/CTAGS.good
@@ -1835,7 +1835,7 @@ Z c-src/h.h       100
 \Ealphaenumerate       tex-src/texinfo.tex     
/^\\def\\Ealphaenumerate{\\Eenumerate}$/
 \Ecapsenumerate        tex-src/texinfo.tex     
/^\\def\\Ecapsenumerate{\\Eenumerate}$/
 \Ecartouche    tex-src/texinfo.tex     /^\\def\\Ecartouche{%$/
-\Edescription  tex-src/texinfo.tex     /^\\def\\Edescription{\\Etable}% 
Neccessary kludge.$/
+\Edescription  tex-src/texinfo.tex     /^\\def\\Edescription{\\Etable}% 
Necessary kludge.$/
 \Edisplay      tex-src/texinfo.tex     
/^\\def\\Edisplay{\\endgroup\\afterenvbreak}%$/
 \Eexample      tex-src/texinfo.tex     /^\\def\\Eexample{\\Elisp}$/
 \Eflushleft    tex-src/texinfo.tex     
/^\\def\\Eflushleft{\\endgroup\\afterenvbreak}%$/
diff --git a/test/manual/etags/cp-src/functions.cpp 
b/test/manual/etags/cp-src/functions.cpp
index 7c353d1..ddd78f1 100644
--- a/test/manual/etags/cp-src/functions.cpp
+++ b/test/manual/etags/cp-src/functions.cpp
@@ -223,7 +223,7 @@ int WorkingDays(Date a, Date b){
        return(wdays);
 }
 
-Date StartDay(Date a,int days){//Function to calculate the apropriate start 
day to finish in days working days
+Date StartDay(Date a,int days){//Function to calculate the appropriate start 
day to finish in days working days
        Date tmp;
        int wdays=0;
        if ( ! a.set() )
diff --git a/test/manual/etags/prol-src/ordsets.prolog 
b/test/manual/etags/prol-src/ordsets.prolog
index 7192129..0fa70f9 100644
--- a/test/manual/etags/prol-src/ordsets.prolog
+++ b/test/manual/etags/prol-src/ordsets.prolog
@@ -120,7 +120,7 @@ ord_intersect(>, Head1, Tail1, _, [Head2|Tail2]) :-
 
 
 %   ord_intersection(+Set1, +Set2, ?Intersection)
-%   is true when Intersection is the intersecton of Set1
+%   is true when Intersection is the intersection of Set1
 %   and Set2, provided that Set1 and Set2 are ordered sets.
 
 ord_intersection([], _, []).
@@ -144,7 +144,7 @@ ord_intersection3([Head2|Tail2], Head1, Tail1, 
Intersection) :-
 
 %   ord_intersection(+Set1, +Set2, ?Intersection, ?Difference)
 %   is true when Intersection is the intersection of Set1 and Set2, 
-%   and Differens is Set2 \ Set1 (like in ord_union/4),
+%   and Difference is Set2 \ Set1 (like in ord_union/4),
 %    provided that Set1 and Set2 are ordered sets.
 
 ord_intersection([], Set2, [], Set2).
diff --git a/test/manual/etags/tex-src/texinfo.tex 
b/test/manual/etags/tex-src/texinfo.tex
index cece96f..8d84f51 100644
--- a/test/manual/etags/tex-src/texinfo.tex
+++ b/test/manual/etags/tex-src/texinfo.tex
@@ -1074,7 +1074,7 @@ July\or August\or September\or October\or November\or 
December\fi
 \def\tablez #1#2#3#4#5#6{%
 \aboveenvbreak %
 \begingroup %
-\def\Edescription{\Etable}% Neccessary kludge.
+\def\Edescription{\Etable}% Necessary kludge.
 \let\itemindex=#1%
 \ifnum 0#3>0 \advance \leftskip by #3\mil \fi %
 \ifnum 0#4>0 \tableindent=#4\mil \fi %
@@ -2937,7 +2937,7 @@ July\or August\or September\or October\or November\or 
December\fi
 \setbox0=\hbox{\printednodename}%
 \ifdim \wd0=0pt%
 \def\printednodename{\ignorespaces #1}%
-%%% Uncommment the following line to make the actual chapter or section title
+%%% Uncomment the following line to make the actual chapter or section title
 %%% appear inside the square brackets.
 %\def\printednodename{#1-title}%
 \fi%



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/cedet/semantic.el b/lisp/cedet/semantic.el
index 71321e1..94bb7fa 100644
--- a/lisp/cedet/semantic.el
+++ b/lisp/cedet/semantic.el
@@ -195,13 +195,13 @@ during a flush when the cache is given a new value of 
nil.")
 (make-variable-buffer-local 'semantic-parse-tree-state)
 
 (defmacro semantic-parse-tree-unparseable ()
-  "Indicate that the current buffer is unparseable.
+  "Indicate that the current buffer is unparsable.
 It is also true that the parse tree will need either updating or
 a rebuild.  This state will be changed when the user edits the buffer."
   '(setq semantic-parse-tree-state 'unparseable))
 
 (defmacro semantic-parse-tree-unparseable-p ()
-  "Return non-nil if the current buffer has been marked unparseable."
+  "Return non-nil if the current buffer has been marked unparsable."
   '(eq semantic-parse-tree-state 'unparseable))
 
 (defmacro semantic-parse-tree-set-needs-update ()
@@ -539,14 +539,14 @@ If the buffer cache is out of date, attempt an 
incremental reparse.
 If the buffer has not been parsed before, or if the incremental reparse
 fails, then parse the entire buffer.
 If a lexical error had been previously discovered and the buffer
-was marked unparseable, then do nothing, and return the cache."
+was marked unparsable, then do nothing, and return the cache."
   (and
    ;; Is this a semantic enabled buffer?
    (semantic-active-p)
    ;; Application hooks say the buffer is safe for parsing
    (run-hook-with-args-until-failure
     'semantic--before-fetch-tags-hook)
    ;; If the buffer was previously marked unparseable,
    ;; then don't waste our time.
    (not (semantic-parse-tree-unparseable-p))
    ;; The parse tree actually needs to be refreshed
@@ -617,7 +617,7 @@ Does nothing if the current buffer doesn't need reparsing."
   ;; do them here, then all the bovination hooks are not run, and
   ;; we save lots of time.
   (cond
    ;; If the buffer was previously marked unparseable,
    ;; then don't waste our time.
    ((semantic-parse-tree-unparseable-p)
     nil)
@@ -539,14 +539,14 @@ If the buffer cache is out of date, attempt an 
    (run-hook-with-args-until-failure
     'semantic--before-fetch-tags-hook)
-   ;; If the buffer was previously marked unparseable,
+   ;; If the buffer was previously marked unparsable,
    ;; then don't waste our time.
    (not (semantic-parse-tree-unparseable-p))
@@ -617,7 +617,7 @@ Does nothing if the current buffer doesn't need reparsing."
   ;; we save lots of time.
   (cond
-   ;; If the buffer was previously marked unparseable,
+   ;; If the buffer was previously marked unparsable,
    ;; then don't waste our time.
    ((semantic-parse-tree-unparseable-p)